import { MinifyOptions } from 'terser';
import type { Plugin } from 'rollup';

/**
 * A rollup plugin for inject codes
 *
 * @param options - options
 * @returns Plugin - injectCode plugin
 */
declare function injectCode(options: OptionsPath): Plugin;

declare function injectCode(options: OptionsCode): Plugin;
export default injectCode;

export declare interface Options {
    /**
     * for es6 import
     *
     * @example ''
     */
    /**
     * for es6 export
     *
     * @example ''
     */
    /**
     * for node require
     *
     * @example ''
     */
    /**
     * for node exports
     *
     * @example ''
     */
    position?: 'before' | 'after';
    /**
     * A string to prepend to the bundle
     */
    intro?: string;
    /**
     * A string to append to the bundle
     */
    outro?: string;
    /**
     * minify the codes
     */
    minify?: boolean;
    /**
     * minify options for terser
     */
    minifyOptions?: MinifyOptions;
}

export declare interface OptionsCode extends Options {
    /**
     * inject code string
     * @description Only one of “path” and “code” needs to be passed in, and "path" has higher priority than "code" when both are passed in
     */
    code: string;
}

export declare interface OptionsPath extends Options {
    /**
     * inject code path
     * @description Only one of “path” and “code” needs to be passed in, and "path" has higher priority than "code" when both are passed in
     */
    path: string;
}

export { }
