/*!
 * rollup-plugin-inject-code v1.1.0
 * A rollup plugin for inject codes
 * (c) 2023-2023 saqqdy 
 * Released under the MIT License.
 */
import { __awaiter, __generator } from 'tslib';
import { readFileSync } from 'fs';
import { minify } from 'terser';

function injectCode(options) {
  if ('path' in options && !options.path) throw new Error('"path" is required');
  if (!('path' in options) && !('code' in options)) throw new Error('“path” and "code" must be passed into at least one');
  return {
    name: 'inject-code',
    renderChunk: function (code) {
      return __awaiter(this, void 0, void 0, function () {
        var injectCode, map, resolvedUrl, result;
        return __generator(this, function (_a) {
          switch (_a.label) {
            case 0:
              injectCode = '';
              if ('path' in options) {
                resolvedUrl = require.resolve(options.path, {
                  paths: [process.cwd()]
                });
                // consola.info('[injectCode] resolvedUrl: ', resolvedUrl)
                injectCode = readFileSync(resolvedUrl, {
                  encoding: 'utf-8'
                });
              } else if ('code' in options) {
                injectCode = options.code;
              }
              injectCode = "".concat('intro' in options ? options.intro + '\n' : '').concat(injectCode).concat('outro' in options ? '\n' + options.outro : '');
              if (!options.minify) return [3 /*break*/, 2];
              return [4 /*yield*/, minify(injectCode, options.minifyOptions)];
            case 1:
              result = _a.sent();
              injectCode = result.code || '';
              map = typeof result.map === 'string' ? JSON.parse(result.map) : result.map;
              return [2 /*return*/, {
                code: options.position === 'after' ? "".concat(code.replace(/;*$/, ';'), "\n").concat(injectCode) : "".concat(injectCode.replace(/;*$/, ';'), "\n").concat(code),
                map: map
              }];
            case 2:
              return [2 /*return*/, options.position === 'after' ? "".concat(code.replace(/;*$/, ';'), "\n").concat(injectCode) : "".concat(injectCode.replace(/;*$/, ';'), "\n").concat(code)];
          }
        });
      });
    }
  };
}

export { injectCode as default };
//# sourceMappingURL=index.mjs.map
